<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DimAngular</name>
    <message>
        <location filename="../DimAngular.js" line="+80"/>
        <source>Arc or first of two lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Łuk lub pierwsza z dwóch linii</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second line</source>
        <translatorcomment>--google--
Zaznacz drugą linię
Wskaż drugą linię [długość/liczba]
Wskaż drugą linie</translatorcomment>
        <translation>Druga linia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Dimension arc location</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Położenie wymiaru łuku</translation>
    </message>
    <message>
        <location filename="../DimAngularInit.js" line="+2"/>
        <source>&amp;Angular</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kątowy</translatorcomment>
        <translation>&amp;Kątowy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw angular dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje wymiar kątowy</translation>
    </message>
</context>
</TS>
